@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: animatedsprite.cpp 3292 2007-05-07 16:22:54Z crush_tmw $
+ *  $Id: animatedsprite.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "animatedsprite.h"
@@ -54,20 +54,14 @@ AnimatedSprite::AnimatedSprite(SpriteDef *sprite):
     play(ACTION_STAND);
 }
 
-AnimatedSprite::AnimatedSprite(const std::string& filename, int variant):
-    mDirection(DIRECTION_DOWN),
-    mLastTime(0),
-    mFrameIndex(0),
-    mFrameTime(0),
-    mAnimation(0),
-    mFrame(0)
+AnimatedSprite *AnimatedSprite::load(const std::string& filename, int variant)
 {
     ResourceManager *resman = ResourceManager::getInstance();
-    mSprite = resman->getSprite(filename, variant);
-    assert(mSprite);
-
-    // Play the stand animation by default
-    play(ACTION_STAND);
+    SpriteDef *s = resman->getSprite(filename, variant);
+    if (!s) return NULL;
+    AnimatedSprite *as = new AnimatedSprite(s);
+    s->decRef();
+    return as;
 }
 
 AnimatedSprite::~AnimatedSprite()
