@@ -18,11 +18,12 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: being.cpp 3303 2007-05-23 22:11:54Z crush_tmw $
+ *  $Id: being.cpp 4048 2008-04-07 16:54:28Z b_lindeijer $
  */
 #include "being.h"
 
 #include <algorithm>
+#include <cassert>
 
 #include "animatedsprite.h"
 #include "equipment.h"
@@ -34,19 +35,17 @@
 
 #include "resources/resourcemanager.h"
 #include "resources/imageset.h"
+#include "resources/iteminfo.h"
 
 #include "gui/gui.h"
 
-#include "resources/resourcemanager.h"
-#include "resources/imageset.h"
-
 #include "utils/dtor.h"
 #include "utils/tostring.h"
 
 int Being::instances = 0;
 ImageSet *Being::emotionSet = NULL;
 
-Being::Being(Uint32 id, Uint16 job, Map *map):
+Being::Being(int id, int job, Map *map):
     mJob(job),
     mX(0), mY(0),
     mAction(0),
@@ -55,16 +54,17 @@ Being::Being(Uint32 id, Uint16 job, Map *map):
     mAttackSpeed(350),
     mEquipment(new Equipment()),
     mId(id),
-    mWeapon(0),
     mWalkSpeed(150),
     mDirection(DOWN),
     mMap(NULL),
-    mHairStyle(0), mHairColor(0),
-    mSex(2),
+    mEquippedWeapon(NULL),
+    mHairStyle(1), mHairColor(0),
+    mGender(2),
     mSpeechTime(0),
     mPx(0), mPy(0),
     mSprites(VECTOREND_SPRITE, NULL),
-    mEquipmentSpriteIDs(VECTOREND_SPRITE, 0)
+    mSpriteIDs(VECTOREND_SPRITE, 0),
+    mSpriteColors(VECTOREND_SPRITE, "")
 {
     setMap(map);
 
@@ -83,7 +83,6 @@ Being::~Being()
 {
     std::for_each(mSprites.begin(), mSprites.end(), make_dtor(mSprites));
     clearPath();
-    setMap(NULL);
 
     for (   std::list<Particle *>::iterator i = mChildParticleEffects.begin();
             i != mChildParticleEffects.end();
@@ -92,6 +91,8 @@ Being::~Being()
         (*i)->kill();
     }
 
+    setMap(NULL);
+
     instances--;
 
     if (instances == 0)
@@ -129,29 +130,18 @@ Being::setPath(const Path &path)
 }
 
 void
-Being::setHairColor(Uint16 color)
+Being::setHairStyle(int style, int color)
 {
-    mHairColor = color;
-    if (mHairColor < 1 || mHairColor > NR_HAIR_COLORS + 1)
-    {
-        mHairColor = 1;
-    }
+    mHairStyle = style < 0 ? mHairStyle : style % NR_HAIR_STYLES;
+    mHairColor = color < 0 ? mHairColor : color % NR_HAIR_COLORS;
 }
 
 void
-Being::setHairStyle(Uint16 style)
+Being::setSprite(int slot, int id, std::string color)
 {
-    mHairStyle = style;
-    if (mHairStyle < 1 || mHairStyle > NR_HAIR_STYLES)
-    {
-        mHairStyle = 1;
-    }
-}
-
-void
-Being::setVisibleEquipment(Uint8 slot, int id)
-{
-    mEquipmentSpriteIDs[slot] = id;
+    assert(slot >= BASE_SPRITE && slot < VECTOREND_SPRITE);
+    mSpriteIDs[slot] = id;
+    mSpriteColors[slot] = color;
 }
 
 void
@@ -164,7 +154,7 @@ Being::setSpeech(const std::string &text, Uint32 time)
 void
 Being::takeDamage(int amount)
 {
-    gcn::Font* font;
+    gcn::Font *font;
     std::string damage = amount ? toString(amount) : "miss";
 
     // Selecting the right color
@@ -174,8 +164,9 @@ Being::takeDamage(int amount)
     }
     else
     {
-        // hit particle effect
-        controlParticle(particleEngine->addEffect("graphics/particles/hit.particle.xml", 0, 0));
+        // Hit particle effect
+        controlParticle(particleEngine->addEffect(
+                    "graphics/particles/hit.particle.xml", 0, 0));
 
         if (getType() == MONSTER)
         {
@@ -187,7 +178,7 @@ Being::takeDamage(int amount)
         }
     }
 
-    // show damage number
+    // Show damage number
     particleEngine->addTextSplashEffect(damage, 255, 255, 255, font,
                                         mPx + 16, mPy + 16);
 }
@@ -204,7 +195,7 @@ void
 Being::setMap(Map *map)
 {
     // Remove sprite from potential previous map
-    if (mMap != NULL)
+    if (mMap)
     {
         mMap->removeSprite(mSpriteIterator);
     }
@@ -212,12 +203,12 @@ Being::setMap(Map *map)
     mMap = map;
 
     // Add sprite to potential new map
-    if (mMap != NULL)
+    if (mMap)
     {
         mSpriteIterator = mMap->addSprite(this);
     }
 
-    //clear particle effect list because child particles became invalid
+    // Clear particle effect list because child particles became invalid
     mChildParticleEffects.clear();
 }
 
@@ -226,7 +217,8 @@ Being::controlParticle(Particle *particle)
 {
     if (particle)
     {
-        particle->disableAutoDelete();  //the effect may not die without the beings permission or we segvault
+        // The effect may not die without the beings permission or we segfault
+        particle->disableAutoDelete();
         mChildParticleEffects.push_back(particle);
     }
 }
@@ -244,20 +236,12 @@ Being::setAction(Uint8 action)
             currentAction = ACTION_SIT;
             break;
         case ATTACK:
-            switch (getWeapon())
+            if (mEquippedWeapon)
             {
-                case 3:
-                    currentAction = ACTION_ATTACK;
-                    break;
-                case 2:
-                    currentAction = ACTION_ATTACK_BOW;
-                    break;
-                case 1:
-                    currentAction = ACTION_ATTACK_STAB;
-                    break;
-                case 0:
-                    currentAction = ACTION_ATTACK;
-                    break;
+                currentAction = mEquippedWeapon->getAttackType();
+            }
+            else {
+                currentAction = ACTION_ATTACK;
             }
             for (int i = 0; i < VECTOREND_SPRITE; i++)
             {
@@ -355,6 +339,12 @@ Being::nextStep()
 
     setDirection(dir);
 
+    if (mMap->tileCollides(node.x, node.y))
+    {
+        setAction(STAND);
+        return;
+    }
+
     mX = node.x;
     mY = node.y;
     setAction(WALK);
@@ -391,10 +381,19 @@ Being::logic()
 
     //Update particle effects
     for (   std::list<Particle *>::iterator i = mChildParticleEffects.begin();
-        i != mChildParticleEffects.end();
-        i++)
+            i != mChildParticleEffects.end();
+
+        )
     {
         (*i)->setPosition((float)mPx + 16.0f, (float)mPy + 32.0f);
+        if (!(*i)->isAlive())
+        {
+            (*i)->kill();
+            i = mChildParticleEffects.erase(i);
+        }
+        else {
+            i++;
+        }
     }
 }
 
@@ -414,19 +413,21 @@ Being::draw(Graphics *graphics, int offsetX, int offsetY) const
 }
 
 void
-Being::drawEmotion(Graphics *graphics, Sint32 offsetX, Sint32 offsetY)
+Being::drawEmotion(Graphics *graphics, int offsetX, int offsetY)
 {
     if (!mEmotion)
         return;
 
-    int px = mPx + offsetX + 3;
-    int py = mPy + offsetY - 60;
+    const int px = mPx + offsetX + 3;
+    const int py = mPy + offsetY - 60;
+    const int emotionIndex = mEmotion - 1;
 
-    graphics->drawImage(emotionSet->get(mEmotion - 1), px, py);
+    if (emotionIndex >= 0 && emotionIndex < emotionSet->size())
+        graphics->drawImage(emotionSet->get(emotionIndex), px, py);
 }
 
 void
-Being::drawSpeech(Graphics *graphics, Sint32 offsetX, Sint32 offsetY)
+Being::drawSpeech(Graphics *graphics, int offsetX, int offsetY)
 {
     int px = mPx + offsetX;
     int py = mPy + offsetY;
@@ -446,46 +447,6 @@ Being::getType() const
     return UNKNOWN;
 }
 
-void
-Being::setWeaponById(Uint16 weapon)
-{
-    //TODO: Use an external file to map weapon IDs to weapon types
-    switch (weapon)
-    {
-    case 529: // iron arrows
-    case 1199: // arrows
-        break;
-
-    case 623: //scythe
-        setWeapon(3);
-        break;
-
-    case 1200: // bow
-    case 530: // short bow
-    case 545: // forest bow
-        setWeapon(2);
-        break;
-
-    case 521: // sharp knife
-        /*  UNCOMMENT TO TEST SHARP KNIFE AS SCYTHE
-         *  setWeapon(3)
-         *  break;
-         */
-    case 522: // dagger
-    case 536: // short sword
-    case 1201: // knife
-        setWeapon(1);
-        break;
-
-    case 0: // unequip
-        setWeapon(0);
-        break;
-
-    default:
-        logger->log("Not a weapon: %d", weapon);
-    }
-}
-
 int
 Being::getOffset(char pos, char neg) const
 {
