@@ -18,9 +18,11 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: beingmanager.cpp 2883 2006-12-03 17:00:07Z b_lindeijer $
+ *  $Id: beingmanager.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
+#include <algorithm>
+
 #include "beingmanager.h"
 
 #include "localplayer.h"
@@ -186,3 +188,30 @@ Being* BeingManager::findNearestLivingBeing(Uint16 x, Uint16 y, int maxdist,
 
     return (maxdist >= dist) ? closestBeing : NULL;
 }
+
+Being* BeingManager::findNearestLivingBeing(Being *aroundBeing, int maxdist,
+                                            Being::Type type)
+{
+    Being *closestBeing = NULL;
+    int dist = 0;
+    int x = aroundBeing->mX;
+    int y = aroundBeing->mY;
+
+    for (BeingIterator i = mBeings.begin(); i != mBeings.end(); i++)
+    {
+        Being *being = (*i);
+        int d = abs(being->mX - x) + abs(being->mY - y);
+
+        if ((being->getType() == type || type == Being::UNKNOWN)
+                && (d < dist || closestBeing == NULL)   // it is closer
+                && being->mAction != Being::DEAD        // no dead beings
+                && being != aroundBeing
+           )
+        {
+            dist = d;
+            closestBeing = being;
+        }
+    }
+
+    return (maxdist >= dist) ? closestBeing : NULL;
+}
