@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: game.cpp 3314 2007-06-03 21:42:42Z the_enemy $
+ *  $Id: game.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "game.h"
@@ -36,7 +36,9 @@
 #include "engine.h"
 #include "flooritemmanager.h"
 #include "graphics.h"
+//#include "itemshortcut.h"
 #include "joystick.h"
+#include "keyboardconfig.h"
 #include "localplayer.h"
 #include "log.h"
 #include "npc.h"
@@ -52,11 +54,13 @@
 #include "gui/gui.h"
 #include "gui/help.h"
 #include "gui/inventorywindow.h"
+//#include "gui/itemshortcutwindow.h"
 #include "gui/menuwindow.h"
 #include "gui/minimap.h"
 #include "gui/ministatus.h"
 #include "gui/npclistdialog.h"
 #include "gui/npc_text.h"
+#include "gui/ok_dialog.h"
 #include "gui/sell.h"
 #include "gui/setup.h"
 #include "gui/skill.h"
@@ -94,6 +98,7 @@ Joystick *joystick = NULL;
 extern Window *weightNotice;
 extern Window *deathNotice;
 ConfirmDialog *exitConfirm = NULL;
+OkDialog *disconnectedDialog = NULL;
 
 ChatWindow *chatWindow;
 MenuWindow *menuWindow;
@@ -115,6 +120,7 @@ TradeWindow *tradeWindow;
 //BuddyWindow *buddyWindow;
 HelpWindow *helpWindow;
 DebugWindow *debugWindow;
+//ItemShortcutWindow *itemShortcutWindow;
 
 BeingManager *beingManager = NULL;
 FloorItemManager *floorItemManager = NULL;
@@ -130,10 +136,11 @@ namespace {
     {
         void action(const gcn::ActionEvent &event)
         {
-            if (event.getId() == "yes") {
+            if (event.getId() == "yes" || event.getId() == "ok") {
                 done = true;
             }
             exitConfirm = NULL;
+            disconnectedDialog = NULL;
         }
     } exitListener;
 }
@@ -194,6 +201,7 @@ void createGuiWindows(Network *network)
     //buddyWindow = new BuddyWindow();
     helpWindow = new HelpWindow();
     debugWindow = new DebugWindow();
+    //itemShortcutWindow = new ItemShortcutWindow();
 
     // Initialize window positions
     //chargeDialog->setPosition(
@@ -206,6 +214,12 @@ void createGuiWindows(Network *network)
     chatWindow->setVisible(true);
     miniStatusWindow->setVisible(true);
     menuWindow->setVisible(true);
+    //itemShortcutWindow->setVisible(true);
+
+    if (config.getValue("logToChat", 0))
+    {
+        logger->setChatWindow(chatWindow);
+    }
 }
 
 /**
@@ -233,6 +247,7 @@ void destroyGuiWindows()
     //delete buddyWindow;
     delete helpWindow;
     delete debugWindow;
+    //delete itemShortcutWindow;
 }
 
 Game::Game(Network *network):
@@ -292,7 +307,6 @@ Game::Game(Network *network):
 
 Game::~Game()
 {
-    delete engine;
     delete player_node;
     destroyGuiWindows();
 
@@ -300,6 +314,7 @@ Game::~Game()
     delete floorItemManager;
     delete joystick;
     delete particleEngine;
+    delete engine;
 
     beingManager = NULL;
     floorItemManager = NULL;
@@ -405,6 +420,18 @@ void Game::logic()
         // Handle network stuff
         mNetwork->flush();
         mNetwork->dispatchMessages();
+
+        if (!mNetwork->isConnected())
+        {
+            if (!disconnectedDialog)
+            {
+                disconnectedDialog = new
+                    OkDialog("Network Error",
+                    "The connection to the server was lost, the program will now quit");
+                disconnectedDialog->addActionListener(&exitListener);
+                disconnectedDialog->requestMoveToTop();
+            }
+        }
     }
 }
 
@@ -426,6 +453,14 @@ void Game::handleInput()
         {
             gcn::Window *requestedWindow = NULL;
 
+            if (setupWindow->isVisible() &&
+                keyboard.getNewKeyIndex() > keyboard.KEY_NO_VALUE)
+            {
+                keyboard.setNewKey((int) event.key.keysym.sym);
+                keyboard.callbackNewKey();
+                keyboard.setNewKeyIndex(keyboard.KEY_NO_VALUE);
+                return;
+            }
             switch (event.key.keysym.sym)
             {
                 case SDLK_F1:
@@ -484,67 +519,90 @@ void Game::handleInput()
                         used = true;
                     }
                     break;
-
-                // Hide certain windows
-                case SDLK_h:
-                    if (!chatWindow->isFocused())
-                    {
-                        statusWindow->setVisible(false);
-                        inventoryWindow->setVisible(false);
-                        skillDialog->setVisible(false);
-                        setupWindow->setVisible(false);
-                        equipmentWindow->setVisible(false);
-                        helpWindow->setVisible(false);
-                        debugWindow->setVisible(false);
-                    }
-                break;
-
-                // Picking up items on the floor
-                case SDLK_g:
-                case SDLK_z:
-                    if (!chatWindow->isFocused())
-                    {
-                        FloorItem *item = floorItemManager->findByCoordinates(
-                                player_node->mX, player_node->mY);
-
-                        // If none below the player, try the tile in front of
-                        // the player
-                        if (!item) {
-                            Uint16 x = player_node->mX;
-                            Uint16 y = player_node->mY;
-                            if (player_node->getDirection() & Being::UP)
-                                y--;
-                            if (player_node->getDirection() & Being::DOWN)
-                                y++;
-                            if (player_node->getDirection() & Being::LEFT)
-                                x--;
-                            if (player_node->getDirection() & Being::RIGHT)
-                                x++;
-
-                            item = floorItemManager->findByCoordinates(x, y);
-                        }
-
-                        if (item)
-                            player_node->pickUp(item);
-
-                        used = true;
-                    }
-                    break;
-
-                    // Quitting confirmation dialog
+                   // Quitting confirmation dialog
                 case SDLK_ESCAPE:
                     if (!exitConfirm) {
                         exitConfirm = new ConfirmDialog(
                                 "Quit", "Are you sure you want to quit?");
                         exitConfirm->addActionListener(&exitListener);
+                        exitConfirm->requestMoveToTop();
+                    }
+                    else
+                    {
+                        exitConfirm->action(gcn::ActionEvent(NULL, "no"));
                     }
-                    exitConfirm->requestMoveToTop();
                     break;
 
                 default:
                     break;
             }
 
+            if (keyboard.isEnabled() && !chatWindow->isFocused())
+            {
+                const int tKey = keyboard.getKeyIndex(event.key.keysym.sym);
+                // Checks if any item shortcut is pressed.
+                /*
+                for (int i = KeyboardConfig::KEY_SHORTCUT_0;
+                    i <= KeyboardConfig::KEY_SHORTCUT_9;
+                    i++)
+                {
+                    if (tKey == i) {
+                        itemShortcut->useItem(
+                                i - KeyboardConfig::KEY_SHORTCUT_0);
+                        break;
+                    }
+                }
+                */
+                switch (tKey) {
+                    case KeyboardConfig::KEY_PICKUP:
+                        {
+                            FloorItem *item = floorItemManager->findByCoordinates(
+                                    player_node->mX, player_node->mY);
+
+                            // If none below the player, try the tile in front of
+                            // the player
+                            if (!item) {
+                                Uint16 x = player_node->mX;
+                                Uint16 y = player_node->mY;
+                                if (player_node->getDirection() & Being::UP)
+                                    y--;
+                                if (player_node->getDirection() & Being::DOWN)
+                                    y++;
+                                if (player_node->getDirection() & Being::LEFT)
+                                    x--;
+                                if (player_node->getDirection() & Being::RIGHT)
+                                    x++;
+
+                                item = floorItemManager->findByCoordinates(x, y);
+                            }
+
+                            if (item)
+                                player_node->pickUp(item);
+
+                            used = true;
+                        }
+                        break;
+                    case KeyboardConfig::KEY_SIT:
+                        // Player sit action
+                        player_node->toggleSit();
+                        used = true;
+                        break;
+                    case KeyboardConfig::KEY_HIDE_WINDOWS:
+                         // Hide certain windows
+                        if (!chatWindow->isFocused())
+                        {
+                            statusWindow->setVisible(false);
+                            inventoryWindow->setVisible(false);
+                            skillDialog->setVisible(false);
+                            setupWindow->setVisible(false);
+                            equipmentWindow->setVisible(false);
+                            helpWindow->setVisible(false);
+                            debugWindow->setVisible(false);
+                        }
+                        break;
+                }
+            }
+
             if (requestedWindow)
             {
                 requestedWindow->setVisible(!requestedWindow->isVisible());
@@ -561,12 +619,6 @@ void Game::handleInput()
             {
                 switch (event.key.keysym.sym)
                 {
-                    case SDLK_s:
-                        // Player sit action
-                        player_node->toggleSit();
-                        used = true;
-                        break;
-
                     case SDLK_p:
                         // Screenshot (picture, hence the p)
                         {
@@ -588,6 +640,17 @@ void Game::handleInput()
                         viewport->toggleDebugPath();
                         used = true;
                         break;
+
+                    case SDLK_t:
+                        // Toggle accepting of incoming trade requests
+                        {
+                            TradeHandler *th = static_cast<TradeHandler*>(
+                                    mTradeHandler.get());
+                            th->setAcceptTradeRequests(
+                                    !th->acceptTradeRequests());
+                        }
+                        used = true;
+                        break;
                 }
 
                 // Emotions
@@ -604,6 +667,8 @@ void Game::handleInput()
                     case SDLK_8: emotion = 8; break;
                     case SDLK_9: emotion = 9; break;
                     case SDLK_0: emotion = 10; break;
+                    case SDLK_MINUS: emotion = 11; break;
+                    case SDLK_EQUALS: emotion = 12; break;
                     default: emotion = 0; break;
                 }
 
@@ -636,42 +701,42 @@ void Game::handleInput()
         }
 
     } // End while
-
+    // If the user is configuring the keys then don't respond.
+    if (!keyboard.isEnabled())
+    {
+       return;
+    }
     // Moving player around
     if (player_node->mAction != Being::DEAD &&
         current_npc == 0 &&
         !chatWindow->isFocused())
     {
         // Get the state of the keyboard keys
-        Uint8* keys;
-        keys = SDL_GetKeyState(NULL);
+        keyboard.refreshActiveKeys();
 
-        Uint16 x = player_node->mX;
-        Uint16 y = player_node->mY;
+        const Uint16 x = player_node->mX;
+        const Uint16 y = player_node->mY;
         unsigned char direction = 0;
 
         // Translate pressed keys to movement and direction
-        if (keys[SDLK_UP] || keys[SDLK_KP8] ||
-                keys[SDLK_KP7] || keys[SDLK_KP9] ||
-                joystick && joystick->isUp())
+        if (keyboard.isKeyActive(keyboard.KEY_MOVE_UP) ||
+            (joystick && joystick->isUp()))
         {
             direction |= Being::UP;
         }
-        else if (keys[SDLK_DOWN] || keys[SDLK_KP2] ||
-                keys[SDLK_KP1] || keys[SDLK_KP3] ||
-                joystick && joystick->isDown())
+        else if (keyboard.isKeyActive(keyboard.KEY_MOVE_DOWN) ||
+                 (joystick && joystick->isDown()))
         {
             direction |= Being::DOWN;
         }
-        if (keys[SDLK_LEFT] || keys[SDLK_KP4] ||
-                keys[SDLK_KP1] || keys[SDLK_KP7] ||
-                joystick && joystick->isLeft())
+
+        if (keyboard.isKeyActive(keyboard.KEY_MOVE_LEFT) ||
+            (joystick && joystick->isLeft()))
         {
             direction |= Being::LEFT;
         }
-        else if (keys[SDLK_RIGHT] || keys[SDLK_KP6] ||
-                keys[SDLK_KP3] || keys[SDLK_KP9] ||
-                joystick && joystick->isRight())
+        else if (keyboard.isKeyActive(keyboard.KEY_MOVE_RIGHT) ||
+                 (joystick && joystick->isRight()))
         {
             direction |= Being::RIGHT;
         }
@@ -679,12 +744,11 @@ void Game::handleInput()
         player_node->setWalkingDir(direction);
 
         // Attacking monsters
-        if (keys[SDLK_LCTRL] || keys[SDLK_RCTRL] ||
+        if ( keyboard.isKeyActive(keyboard.KEY_ATTACK) ||
                 joystick && joystick->buttonPressed(0))
         {
             Being *target = NULL;
-            bool newTarget = keys[SDLK_LSHIFT] || keys[SDLK_RSHIFT];
-
+            bool newTarget = keyboard.isKeyActive(keyboard.KEY_TARGET);
             // A set target has highest priority
             if (newTarget || !player_node->getTarget())
             {
@@ -710,8 +774,22 @@ void Game::handleInput()
             player_node->attack(target, newTarget);
         }
 
+        // Target the nearest player if 'q' is pressed
+        if ( keyboard.isKeyActive(keyboard.KEY_TARGET_PLAYER) )
+        //if (keys[SDLK_q])
+        {
+            Being *target =
+                beingManager->findNearestLivingBeing(player_node, 20, Being::PLAYER);
+
+            if (target)
+            {
+                player_node->setTarget(target);
+            }
+        }
+
         // Target the nearest monster if 'a' pressed
-        if (keys[SDLK_a])
+        if ( keyboard.isKeyActive(keyboard.KEY_TARGET_CLOSEST) )
+        //if (keys[SDLK_a])
         {
             Being *target =
                 beingManager->findNearestLivingBeing(x, y, 20, Being::MONSTER);
@@ -726,8 +804,7 @@ void Game::handleInput()
         {
             if (joystick->buttonPressed(1))
             {
-                FloorItem *item = floorItemManager->findByCoordinates(
-                        player_node->mX, player_node->mY);
+                FloorItem *item = floorItemManager->findByCoordinates(x, y);
 
                 if (item)
                     player_node->pickUp(item);
