@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: chatinput.cpp 3035 2007-01-14 14:54:39Z b_lindeijer $
+ *  $Id: chatinput.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "chatinput.h"
@@ -26,9 +26,11 @@
 ChatInput::ChatInput()
 {
     setVisible(false);
+
+    addFocusListener(this);
 }
 
-void ChatInput::focusLost()
+void ChatInput::focusLost(const gcn::Event &event)
 {
     setVisible(false);
 }
