@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: chatinput.h 3035 2007-01-14 14:54:39Z b_lindeijer $
+ *  $Id: chatinput.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_CHATINPUT_H
@@ -26,10 +26,12 @@
 
 #include "textfield.h"
 
+#include <guichan/focuslistener.hpp>
+
 /**
  * The chat input hides when it loses focus. It is also invisible by default.
  */
-class ChatInput : public TextField
+class ChatInput : public TextField, public gcn::FocusListener
 {
     public:
         /**
@@ -41,7 +43,7 @@ class ChatInput : public TextField
          * Called if the chat input loses focus. It will set itself to
          * invisible as result.
          */
-        void focusLost();
+        void focusLost(const gcn::Event &event);
 };
 
 #endif
