@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: equipmentwindow.cpp 3218 2007-03-21 21:56:12Z b_lindeijer $
+ *  $Id: equipmentwindow.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "equipmentwindow.h"
@@ -37,6 +37,7 @@ EquipmentWindow::EquipmentWindow(Equipment *equipment):
     Window("Equipment"), mEquipment(equipment)
 {
     setWindowName("Equipment");
+    setCloseButton(true);
     setDefaultSize(5, 230, 200, 120);
     loadWindowState();
 }
@@ -65,7 +66,7 @@ void EquipmentWindow::draw(gcn::Graphics *graphics)
         }
 
         image = item->getInfo().getImage();
-        dynamic_cast<Graphics*>(graphics)->drawImage(
+        static_cast<Graphics*>(graphics)->drawImage(
                 image, 36 * (i % 4) + 10, 36 * (i / 4) + 25);
     }
 
@@ -77,7 +78,7 @@ void EquipmentWindow::draw(gcn::Graphics *graphics)
 
     image = item->getInfo().getImage();
 
-    dynamic_cast<Graphics*>(graphics)->drawImage(image, 160, 25);
+    static_cast<Graphics*>(graphics)->drawImage(image, 160, 25);
     graphics->drawText(toString(item->getQuantity()), 170, 62,
             gcn::Graphics::CENTER);
 }
