@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: inventorywindow.h 3035 2007-01-14 14:54:39Z b_lindeijer $
+ *  $Id: inventorywindow.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_INVENTORYWINDOW_H
@@ -26,8 +26,9 @@
 
 #include <guichan/actionlistener.hpp>
 
-#include "window.h"
 #include "selectionlistener.h"
+#include "window.h"
+#include "windowlistener.h"
 
 #include "../guichanfwd.h"
 
@@ -39,7 +40,8 @@ class ItemContainer;
  *
  * \ingroup Interface
  */
-class InventoryWindow : public Window, gcn::ActionListener, SelectionListener
+class InventoryWindow : public Window, gcn::ActionListener, SelectionListener,
+    WindowListener
 {
     public:
         /**
@@ -59,14 +61,8 @@ class InventoryWindow : public Window, gcn::ActionListener, SelectionListener
 
         void mouseClicked(gcn::MouseEvent &event);
 
-        void mouseDragged(gcn::MouseEvent &event);
-
         Item* getItem();
 
-        void loadWindowState();
-
-        void resetToDefaultSize();
-
         /**
          * Updates labels to currently selected item.
          *
@@ -74,11 +70,14 @@ class InventoryWindow : public Window, gcn::ActionListener, SelectionListener
          */
         void selectionChanged(const SelectionEvent &event);
 
+        /**
+         * Called whenever the window is resized.
+         */
+        void windowResized(const WindowEvent &event);
+
     private:
         void updateButtons();    /**< Updates button states. */
 
-        void updateWidgets();    /**< Updates widgets size/position. */
-
         ItemContainer *mItems;
 
         gcn::Button *mUseButton, *mDropButton;
