@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: ministatus.cpp 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: ministatus.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "ministatus.h"
@@ -78,6 +78,7 @@ MiniStatusWindow::MiniStatusWindow():
 
     setDefaultSize(0, 0, mXpBar->getX() + mXpBar->getWidth(),
                    mXpBar->getY() + mXpBar->getHeight());
+    loadWindowState();
 }
 
 void MiniStatusWindow::update()
@@ -98,7 +99,8 @@ void MiniStatusWindow::update()
 
     mHpBar->setProgress((float) player_node->mHp / player_node->mMaxHp);
     // mMpBar->setProgress((float) player_node->mMp / player_node->mMaxMp);
-    mXpBar->setProgress((float) player_node->mXp / player_node->mXpForNextLevel);
+    mXpBar->setProgress(
+            (float) player_node->getXp() / player_node->mXpForNextLevel);
 
     // Update labels
     mHpLabel->setCaption(toString(player_node->mHp));
@@ -106,7 +108,7 @@ void MiniStatusWindow::update()
 
     std::stringstream updatedText;
     updatedText << (int) (
-            (float) player_node->mXp /
+            (float) player_node->getXp() /
             player_node->mXpForNextLevel * 100) << "%";
 
     // Displays the number of monsters to next lvl
