@@ -18,9 +18,11 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: playerbox.cpp 3018 2007-01-07 22:46:12Z b_lindeijer $
+ *  $Id: playerbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
+#include <algorithm>
+
 #include "playerbox.h"
 
 #include "../player.h"
@@ -80,7 +82,11 @@ PlayerBox::draw(gcn::Graphics *graphics)
     if (mPlayer)
     {
         // Draw character
-        mPlayer->draw(dynamic_cast<Graphics*>(graphics), 40, 42);
+        int x, y, bs;
+        bs = getBorderSize();
+        x = getWidth() / 2 - 16 + bs;
+        y = getHeight() / 2 + bs;
+        mPlayer->draw(static_cast<Graphics*>(graphics), x, y);
     }
 }
 
@@ -92,5 +98,5 @@ PlayerBox::drawBorder(gcn::Graphics *graphics)
     w = getWidth() + bs * 2;
     h = getHeight() + bs * 2;
 
-    dynamic_cast<Graphics*>(graphics)->drawImageRect(0, 0, w, h, background);
+    static_cast<Graphics*>(graphics)->drawImageRect(0, 0, w, h, background);
 }
