@@ -18,15 +18,18 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup.cpp 3035 2007-01-14 14:54:39Z b_lindeijer $
+ *  $Id: setup.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
+#include <algorithm>
+
 #include "setup.h"
 
 #include "button.h"
 #include "setup_audio.h"
 #include "setup_joystick.h"
 #include "setup_video.h"
+#include "setup_keyboard.h"
 #include "tabbedcontainer.h"
 
 #include "../utils/dtor.h"
@@ -42,7 +45,8 @@ extern Window *skillDialog;
 Setup::Setup():
     Window("Setup")
 {
-    int width = 230;
+    setCloseButton(true);
+    int width = 250;
     int height = 245;
     setContentSize(width, height);
 
@@ -58,7 +62,7 @@ Setup::Setup():
     }
 
     TabbedContainer *panel = new TabbedContainer();
-    panel->setDimension(gcn::Rectangle(5, 5, 220, 205));
+    panel->setDimension(gcn::Rectangle(5, 5, 250, 205));
     panel->setOpaque(false);
 
     SetupTab *tab;
@@ -75,6 +79,10 @@ Setup::Setup():
     panel->addTab(tab, "Joystick");
     mTabs.push_back(tab);
 
+    tab = new Setup_Keyboard();
+    panel->addTab(tab, "Keyboard");
+    mTabs.push_back(tab);
+
     add(panel);
 
     setLocationRelativeTo(getParent());
