@@ -95,6 +95,7 @@ void ShopListBox::draw(gcn::Graphics *gcnGraphics)
                 graphics->drawImage(icon, 1, y);
             }
         }
+        graphics->setColor(gcn::Color(0, 0, 0));
         graphics->drawText(mListModel->getElementAt(i), ITEM_ICON_SIZE + 5,
                 y + (ITEM_ICON_SIZE - getFont()->getHeight()) / 2);
     }
@@ -113,10 +114,10 @@ void ShopListBox::setSelected(int selected)
                              std::max(-1, selected));
 
         gcn::Widget *parent = getParent();
-        if (parent)
+        if (parent && mSelected >= 0)
         {
             gcn::Rectangle scroll;
-            scroll.y = (mSelected < 0) ? 0 : mRowHeight * mSelected;
+            scroll.y = mRowHeight * mSelected;
             scroll.height = mRowHeight;
             parent->showWidgetPart(this, scroll);
         }
@@ -129,24 +130,8 @@ void ShopListBox::mousePressed(gcn::MouseEvent &event)
 {
     if (event.getButton() == gcn::MouseEvent::LEFT)
     {
-        bool enoughMoney = false;
-        int y = event.getY();
-
-        if (mShopItems && mPriceCheck)
-        {
-            if (mPlayerMoney >= mShopItems->at(y / mRowHeight).price)
-                enoughMoney = true;
-        }
-        else // Old Behaviour
-        {
-            enoughMoney = true;
-        }
-
-        if (enoughMoney)
-        {
-            setSelected(y / mRowHeight);
-            generateAction();
-        }
+        setSelected(event.getY() / mRowHeight);
+        generateAction();
     }
 }
 
