@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: status.h 3035 2007-01-14 14:54:39Z b_lindeijer $
+ *  $Id: status.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_STATUS_H
@@ -41,7 +41,8 @@ class ProgressBar;
  *
  * \ingroup Interface
  */
-class StatusWindow : public Window, public gcn::ActionListener {
+class StatusWindow : public Window, public gcn::ActionListener
+{
     public:
         /**
          * Constructor.
