@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: updatewindow.cpp 3236 2007-03-24 22:38:25Z crush_tmw $
+ *  $Id: updatewindow.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "updatewindow.h"
@@ -46,6 +46,8 @@
 
 #include "../resources/resourcemanager.h"
 
+extern std::string homeDir;
+
 /**
  * Calculates the Alder-32 checksum for the given file.
  */
@@ -119,7 +121,7 @@ UpdaterWindow::UpdaterWindow():
 
     mUpdateHost =
         config.getValue("updatehost", "http://updates.themanaworld.org");
-    mBasePath = config.getValue("homeDir", ".");
+    mBasePath = homeDir;
 
     // Try to download the updates list
     download();
@@ -209,12 +211,6 @@ void UpdaterWindow::loadNews()
     mScrollArea->setVerticalScrollAmount(0);
 }
 
-void UpdaterWindow::addRow(const std::string &row)
-{
-    mBrowserBox->addRow(row);
-    mScrollArea->setVerticalScrollAmount(mScrollArea->getVerticalMaxScroll());
-}
-
 int UpdaterWindow::updateProgress(void *ptr,
                                   double dt, double dn, double ut, double un)
 {
@@ -311,17 +307,20 @@ int UpdaterWindow::downloadThread(void *ptr)
                 switch (res)
                 {
                 case CURLE_COULDNT_CONNECT:
-                    // give more debug info on that error
-                    std::cerr << "curl error " << res << ": "
-                              << uw->mCurlError << " " << url.c_str()
-                              << std::endl;
-                    break;
-
                 default:
                     std::cerr << "curl error " << res << ": "
                               << uw->mCurlError << " host: " << url.c_str()
                               << std::endl;
+                    break;
                 }
+
+                if (!uw->mStoreInMemory)
+                {
+                    fclose(outfile);
+                    ::remove(outFilename.c_str());
+                }
+                attempts++;
+                continue;
             }
 
             curl_easy_cleanup(curl);
@@ -416,11 +415,12 @@ void UpdaterWindow::logic()
                 }
                 mThread = NULL;
             }
-            addRow("");
-            addRow("##1  The update process is incomplete.");
-            addRow("##1  It is strongly recommended that");
-            addRow("##1  you try again later");
-            addRow(mCurlError);
+            mBrowserBox->addRow("");
+            mBrowserBox->addRow("##1  The update process is incomplete.");
+            mBrowserBox->addRow("##1  It is strongly recommended that");
+            mBrowserBox->addRow("##1  you try again later");
+            mBrowserBox->addRow(mCurlError);
+            mScrollArea->setVerticalScrollAmount(mScrollArea->getVerticalMaxScroll());
             mDownloadStatus = UPDATE_COMPLETE;
             break;
         case UPDATE_NEWS:
