@@ -18,14 +18,14 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: vbox.cpp 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: vbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "vbox.h"
 
 void VBox::draw(gcn::Graphics *graphics)
 {
-    if (mWidgets.size() == 0)
+    if (mWidgets.empty())
     {
         return;
     }
