@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: viewport.h 3301 2007-05-23 21:35:01Z b_lindeijer $
+ *  $Id: viewport.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_VIEWPORT_H_
@@ -120,27 +120,21 @@ class Viewport : public WindowContainer, public gcn::MouseListener,
          * Returns camera x offset in tiles.
          */
         int
-        getCameraX() { return mCameraX; }
+        getCameraX() { return mTileViewX; }
 
         /**
          * Returns camera y offset in tiles.
          */
         int
-        getCameraY() { return mCameraY; }
+        getCameraY() { return mTileViewY; }
+
+        /**
+         * Changes viewpoint by relative pixel coordinates.
+         */
+        void
+        scrollBy (float x, float y) { mPixelViewX += x; mPixelViewY += y; }
 
     private:
-        /**
-         * Shows a popup for a floor item.
-         * TODO Find some way to get rid of FloorItem here
-         */
-        void showPopup(int x, int y, FloorItem *floorItem);
-
-        /**
-         * Shows a popup for a being.
-         * TODO Find some way to get rid of Being here
-         */
-        void showPopup(int x, int y, Being *being);
-
         /**
          * Helper function for loading target cursors
          */
@@ -165,10 +159,12 @@ class Viewport : public WindowContainer, public gcn::MouseListener,
 
         int mScrollRadius;
         int mScrollLaziness;
-        float mViewX;              /**< Current viewpoint in pixels. */
-        float mViewY;              /**< Current viewpoint in pixels. */
-        int mCameraX;              /**< Current viewpoint in tiles. */
-        int mCameraY;              /**< Current viewpoint in tiles. */
+        int mScrollCenterOffsetX;
+        int mScrollCenterOffsetY;
+        float mPixelViewX;              /**< Current viewpoint in pixels. */
+        float mPixelViewY;              /**< Current viewpoint in pixels. */
+        int mTileViewX;              /**< Current viewpoint in tiles. */
+        int mTileViewY;              /**< Current viewpoint in tiles. */
         bool mShowDebugPath;       /**< Show a path from player to pointer. */
 
         /** Images of in range target cursor. */
@@ -187,7 +183,6 @@ class Viewport : public WindowContainer, public gcn::MouseListener,
         int mWalkTime;
 
         PopupMenu *mPopupMenu;     /**< Popup menu. */
-        bool mPopupActive;
 };
 
 #endif
