@@ -18,14 +18,16 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: inventory.cpp 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: inventory.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "inventory.h"
 
 #include <algorithm>
+#include <cassert>
 
 #include "item.h"
+#include "log.h"
 
 struct SlotUsed : public std::unary_function<Item, bool>
 {
@@ -49,7 +51,7 @@ Inventory::~Inventory()
 
 Item* Inventory::getItem(int index)
 {
-    if (index < 0 || index > INVENTORY_SIZE)
+    if (index < 0 || index >= INVENTORY_SIZE)
     {
         return 0;
     }
@@ -64,6 +66,11 @@ void Inventory::addItem(int id, int quantity, bool equipment)
 
 void Inventory::addItem(int index, int id, int quantity, bool equipment)
 {
+    if (index < 0 || index >= INVENTORY_SIZE) {
+        logger->log("Warning: invalid inventory index: %d", index);
+        return;
+    }
+
     mItems[index].setId(id);
     mItems[index].increaseQuantity(quantity);
     mItems[index].setEquipment(equipment);
