@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: joystick.h 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: joystick.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_JOYSTICK_H
@@ -32,15 +32,12 @@ class Joystick
         /**
          * Number of buttons we can handle.
          */
-        static const unsigned char MAX_BUTTONS = 6;
+        enum { MAX_BUTTONS = 6 };
 
         /**
          * Directions, to be used as bitmask values.
          */
-        static const char UP = 1;
-        static const char DOWN = 2;
-        static const char LEFT = 4;
-        static const char RIGHT = 8;
+        enum { UP = 1, DOWN = 2, LEFT = 4, RIGHT = 8 };
 
         /**
          * Initializes the joystick subsystem.
