@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: main.cpp 3314 2007-06-03 21:42:42Z the_enemy $
+ *  $Id: main.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "main.h"
@@ -45,8 +45,10 @@
 #endif
 
 #include "configuration.h"
+#include "keyboardconfig.h"
 #include "game.h"
 #include "graphics.h"
+//#include "itemshortcut.h"
 #include "lockedarray.h"
 #include "localplayer.h"
 #include "log.h"
@@ -72,7 +74,6 @@
 #include "net/messageout.h"
 #include "net/network.h"
 
-#include "resources/equipmentdb.h"
 #include "resources/image.h"
 #include "resources/itemdb.h"
 #include "resources/monsterdb.h"
@@ -85,6 +86,8 @@
 #include <SDL_syswm.h>
 #endif
 
+std::string homeDir;
+
 // Account infos
 char n_server, n_character;
 
@@ -103,6 +106,7 @@ Music *bgm;
 
 Configuration config;         /**< XML file configuration reader */
 Logger *logger;               /**< Log object */
+KeyboardConfig keyboard;
 
 /**
  * A structure holding the values of various options that can be passed from
@@ -135,7 +139,7 @@ struct Options
  */
 void init_engine(const Options &options)
 {
-    std::string homeDir = std::string(PHYSFS_getUserDir()) + "/.tmw";
+    homeDir = std::string(PHYSFS_getUserDir()) + "/.tmw";
 #if defined WIN32
     if (!CreateDirectory(homeDir.c_str(), 0) &&
             GetLastError() != ERROR_ALREADY_EXISTS)
@@ -150,10 +154,16 @@ void init_engine(const Options &options)
                   << std::endl;
         exit(1);
     }
-            
+
     // Set log file
     logger->setLogFile(homeDir + std::string("/tmw.log"));
 
+    #ifdef PACKAGE_VERSION
+        logger->log("Starting The Mana World Version %s", PACKAGE_VERSION);
+    #else
+        logger->log("Starting The Mana World - Version not defined");
+    #endif
+
     // Initialize SDL
     logger->log("Initializing SDL...");
     if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) < 0) {
@@ -224,7 +234,7 @@ void init_engine(const Options &options)
     config.setValue("fpslimit", 60);
     config.setValue("updatehost", "http://updates.themanaworld.org");
     config.setValue("customcursor", 1);
-    config.setValue("homeDir", homeDir);
+    config.setValue("ChatLogLength", 128);
 
     // Checking if the configuration file exists... otherwise creates it with
     // default options !
@@ -279,23 +289,27 @@ void init_engine(const Options &options)
     graphics = new Graphics();
 #endif
 
-    int width = (int)config.getValue("screenwidth", 800);
-    int height = (int)config.getValue("screenheight", 600);
+    int width = (int) config.getValue("screenwidth", defaultScreenWidth);
+    int height = (int) config.getValue("screenheight", defaultScreenHeight);
     int bpp = 0;
-    bool fullscreen = ((int)config.getValue("screen", 0) == 1);
-    bool hwaccel = ((int)config.getValue("hwaccel", 0) == 1);
+    bool fullscreen = ((int) config.getValue("screen", 0) == 1);
+    bool hwaccel = ((int) config.getValue("hwaccel", 0) == 1);
 
     // Try to set the desired video mode
     if (!graphics->setVideoMode(width, height, bpp, fullscreen, hwaccel))
     {
-        std::cerr << "Couldn't set " << width << "x" << height << "x" <<
-            bpp << " video mode: " << SDL_GetError() << std::endl;
+        std::cerr << "Couldn't set "
+                  << width << "x" << height << "x" << bpp << " video mode: "
+                  << SDL_GetError() << std::endl;
         exit(1);
     }
 
     // Initialize for drawing
     graphics->_beginDraw();
 
+    // Initialize the item shortcuts.
+    //itemShortcut = new ItemShortcut();
+
     gui = new Gui(graphics);
     state = UPDATE_STATE; /**< Initial game state */
 
@@ -304,20 +318,29 @@ void init_engine(const Options &options)
         if (config.getValue("sound", 0) == 1) {
             sound.init();
         }
-        sound.setSfxVolume((int) config.getValue("sfxVolume", 100));
-        sound.setMusicVolume((int) config.getValue("musicVolume", 60));
+        sound.setSfxVolume((int) config.getValue("sfxVolume",
+                    defaultSfxVolume));
+        sound.setMusicVolume((int) config.getValue("musicVolume",
+                    defaultMusicVolume));
     }
     catch (const char *err) {
         state = ERROR_STATE;
         errorMessage = err;
         logger->log("Warning: %s", err);
     }
+
+    // Initialize keyboard
+    keyboard.init();
 }
 
 /** Clear the engine */
 void exit_engine()
 {
+    // Before config.write() since it writes the shortcuts to the config
+    //delete itemShortcut;
+
     config.write();
+
     delete gui;
     delete graphics;
 
@@ -328,7 +351,6 @@ void exit_engine()
     sound.close();
 
     // Unload XML databases
-    EquipmentDB::unload();
     ItemDB::unload();
     MonsterDB::unload();
 
@@ -423,7 +445,6 @@ void loadUpdates()
     const std::string updatesFile = "updates/resources2.txt";
     ResourceManager *resman = ResourceManager::getInstance();
     std::vector<std::string> lines = resman->loadTextFile(updatesFile);
-    std::string homeDir = config.getValue("homeDir", "");
 
     for (unsigned int i = 0; i < lines.size(); ++i)
     {
@@ -594,7 +615,7 @@ int main(int argc, char *argv[])
                             progressBar->getY() + 4);
     progressBar->setVisible(false);
 
-    sound.playMusic(TMW_DATADIR "data/music/Magick - Real.ogg");
+    sound.playMusic("Magick - Real.ogg");
 
     loginData.username = options.username;
     if (loginData.username.empty()) {
@@ -623,7 +644,9 @@ int main(int argc, char *argv[])
 
                 case SDL_KEYDOWN:
                     if (event.key.keysym.sym == SDLK_ESCAPE)
+                    {
                         state = EXIT_STATE;
+                    }
                     break;
             }
 
@@ -713,7 +736,6 @@ int main(int argc, char *argv[])
                         false);
 
                     // Load XML databases
-                    EquipmentDB::load();
                     ItemDB::load();
                     MonsterDB::load();
                     state = LOGIN_STATE;
@@ -806,7 +828,6 @@ int main(int argc, char *argv[])
                     break;
 
                 case CHAR_CONNECT_STATE:
-                    logger->log("Char: %i\n", loginData.sex);
                     progressBar->setVisible(true);
                     progressLabel->setCaption(
                             "Connecting to character server...");
@@ -815,7 +836,6 @@ int main(int argc, char *argv[])
                     break;
 
                 case ACCOUNT_STATE:
-                    logger->log("Account: %i", loginData.sex);
                     progressBar->setVisible(true);
                     progressLabel->setCaption(
                             "Connecting to account server...");
@@ -830,6 +850,12 @@ int main(int argc, char *argv[])
         }
     }
 
+#ifdef PACKAGE_VERSION
+    delete versionLabel;
+#endif
+    delete progressBar;
+    delete progressLabel;
+
     delete network;
     SDLNet_Quit();
 
