@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: map.h 3290 2007-05-04 13:09:25Z crush_tmw $
+ *  $Id: map.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_MAP_H_
@@ -39,7 +39,6 @@ class Tileset;
 struct PATH_NODE;
 
 typedef std::vector<Tileset*> Tilesets;
-typedef Tilesets::iterator TilesetIterator;
 typedef std::list<Sprite*> Sprites;
 typedef Sprites::iterator SpriteIterator;
 
@@ -134,39 +133,34 @@ class Map : public Properties
          */
         void setWalk(int x, int y, bool walkable);
 
-        /**
-         * Tell if a tile is walkable or not, includes checking beings.
-         */
-        bool getWalk(int x, int y);
-
         /**
          * Tell if a tile collides, not including a check on beings.
          */
-        bool tileCollides(int x, int y);
+        bool tileCollides(int x, int y) const;
 
         /**
          * Returns the width of this map.
          */
         int
-        getWidth() { return mWidth; }
+        getWidth() const { return mWidth; }
 
         /**
          * Returns the height of this map.
          */
         int
-        getHeight() { return mHeight; }
+        getHeight() const { return mHeight; }
 
         /**
          * Returns the tile width of this map.
          */
         int
-        getTileWidth() { return mTileWidth; }
+        getTileWidth() const { return mTileWidth; }
 
         /**
          * Returns the tile height used by this map.
          */
         int
-        getTileHeight() { return mTileHeight; }
+        getTileHeight() const { return mTileHeight; }
 
         /**
          * Find a path from one location to the next.
@@ -202,27 +196,26 @@ class Map : public Properties
          * Converts a global tile id to the Image* pointing to the associated
          * tile image.
          */
-        Image*
-        getTileWithGid(int gid);
+        Image* getTileWithGid(int gid) const;
 
         /**
          * Finds the tile set that a tile with the given global id is part of.
          */
-        Tileset*
-        getTilesetWithGid(int gid);
+        Tileset* getTilesetWithGid(int gid) const;
 
         /**
          * Tells whether a tile is occupied by a being.
          */
-        bool occupied(int x, int y);
+        bool occupied(int x, int y) const;
 
         /**
          * Tells whether the given coordinates fall within the map boundaries.
          */
-        bool contains(int x, int y);
+        bool contains(int x, int y) const;
 
         int mWidth, mHeight;
         int mTileWidth, mTileHeight;
+        int mMaxTileHeight;
         MetaTile *mMetaTiles;
         Image **mTiles;
 
