@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: openglgraphics.h 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: openglgraphics.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_OPENGLGRAPHICS_H
@@ -38,7 +38,8 @@ class OpenGLGraphics : public Graphics
         bool drawImage(Image *image,
                        int srcX, int srcY,
                        int dstX, int dstY,
-                       int width, int height);
+                       int width, int height,
+                       bool useColor);
 
         void updateScreen();
 
@@ -50,11 +51,6 @@ class OpenGLGraphics : public Graphics
 
         void setColor(const gcn::Color &color);
 
-        void drawImage(const gcn::Image* image,
-                       int srcX, int srcY,
-                       int dstX, int dstY,
-                       int width, int height);
-
         void drawPoint(int x, int y);
 
         void drawLine(int x1, int y1, int x2, int y2);
@@ -74,8 +70,6 @@ class OpenGLGraphics : public Graphics
 
     protected:
         void setTexturingAndBlending(bool enable);
-        void drawTexedQuad(int x, int y, int w, int h,
-                           float texX1, float texY1, float texX2, float texY2);
 
     private:
         bool mAlpha, mTexture;
