@@ -18,9 +18,11 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id$
+ *  $Id: monsterdb.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
+#include <algorithm>
+
 #include "monsterdb.h"
 
 #include "resourcemanager.h"
@@ -120,19 +122,19 @@ MonsterDB::load()
 
                 if (event == "hit")
                 {
-                    currentInfo->addSound(EVENT_HIT, filename);
+                    currentInfo->addSound(MONSTER_EVENT_HIT, filename);
                 }
                 else if (event == "miss")
                 {
-                    currentInfo->addSound(EVENT_MISS, filename);
+                    currentInfo->addSound(MONSTER_EVENT_MISS, filename);
                 }
                 else if (event == "hurt")
                 {
-                    currentInfo->addSound(EVENT_HURT, filename);
+                    currentInfo->addSound(MONSTER_EVENT_HURT, filename);
                 }
                 else if (event == "die")
                 {
-                    currentInfo->addSound(EVENT_DIE, filename);
+                    currentInfo->addSound(MONSTER_EVENT_DIE, filename);
                 }
                 else
                 {
@@ -140,10 +142,18 @@ MonsterDB::load()
                                 filename, event.c_str(), currentInfo->getName().c_str());
                 }
             }
+
+            if (xmlStrEqual(spriteNode->name, BAD_CAST "particlefx"))
+            {
+                currentInfo->addParticleEffect(
+                    (const char*) spriteNode->xmlChildrenNode->content);
+            }
         }
         mMonsterInfos[XML::getProperty(monsterNode, "id", 0)] = currentInfo;
     }
 
+    xmlFreeDoc(doc);
+
     mLoaded = true;
 }
 
