@@ -18,21 +18,15 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: resource.cpp 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: resource.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
-#include "resource.h"
-
 #include <cassert>
 
+#include "resource.h"
+
 #include "resourcemanager.h"
 
-
-Resource::Resource(const std::string &idPath):
-    mRefCount(0), mIdPath(idPath)
-{
-}
-
 Resource::~Resource()
 {
 }
@@ -51,10 +45,10 @@ Resource::decRef()
 
     mRefCount--;
 
-    if (mRefCount == 0) {
-        // Make sure resource manager won't refer to deleted resource
+    if (mRefCount == 0)
+    {
+        // Warn the manager that this resource is no longer used.
         ResourceManager *resman = ResourceManager::getInstance();
-        resman->release(mIdPath);
-        delete this;
+        resman->release(this);
     }
 }
