@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textparticle.h 3303 2007-05-23 22:11:54Z crush_tmw $
+ *  $Id: textparticle.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TEXTPARTICLE_H
@@ -33,21 +33,26 @@
 class TextParticle : public Particle
 {
     public:
-        TextParticle(Map *map, const std::string &text,
-                int colorR, int colorG, int colorB, gcn::Font *font);
         /**
-         * Draws the particle image
+         * Constructor.
+         */
+        TextParticle(Map *map, const std::string &text,
+                     int colorR, int colorG, int colorB,
+                     gcn::Font *font);
+        /**
+         * Draws the particle image.
          */
         virtual void
         draw(Graphics *graphics, int offsetX, int offsetY) const;
 
         // hack to improve text visibility
-        virtual int getPixelY() const { return (int)(mPosY + mPosZ); }
+        virtual int getPixelY() const
+        { return (int) (mPos.y + mPos.z); }
 
     private:
-        std::string mText;              /**< Text of the particle */
-        gcn::Font *mTextFont;           /**< Font used for drawing the text */
-        int mColorR, mColorG, mColorB;  /**< Color used for drawing the text */
+        std::string mText;             /**< Text of the particle. */
+        gcn::Font *mTextFont;          /**< Font used for drawing the text. */
+        int mColorR, mColorG, mColorB; /**< Color used for drawing the text. */
 };
 
 #endif
