@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tileset.h 3218 2007-03-21 21:56:12Z b_lindeijer $
+ *  $Id: tileset.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_TILESET_H_
@@ -36,7 +36,7 @@ class Tileset : public ImageSet
          * Constructor.
          */
         Tileset(Image *img, int w, int h, int firstGid):
-            ImageSet("", img, w, h),
+            ImageSet(img, w, h),
             mFirstGid(firstGid)
         {
         }
