@@ -18,11 +18,11 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tostring.h 2822 2006-11-05 14:30:53Z b_lindeijer $
+ *  $Id: tostring.h 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #ifndef _TMW_UTILS_TOSTRING_H
-#define _TMW_UTISL_TOSTRING_H
+#define _TMW_UTILS_TOSTRING_H
 
 #include <sstream>
 
